@@ -53,7 +53,10 @@ class ReadingTest(unittest.TestCase):
     
     def test_mode(self):
         self.failUnlessEqual(self.c.mode, "r")
-    
+
+    def test_collection(self):
+        self.failUnlessEqual(self.c.encoding, "iso-8859-1")
+
     def test_iter(self):
         self.failUnless(iter(self.c))
     
@@ -106,7 +109,7 @@ class ReadingTest(unittest.TestCase):
 
     def test_crs(self):
         crs = self.c.crs
-        self.failUnlessEqual(crs['ellps'], 'WGS84')
+        self.failUnlessEqual(crs['datum'], 'WGS84')
         self.failUnless(crs['no_defs'])
 
     def test_closed_crs(self):
@@ -119,7 +122,7 @@ class ReadingTest(unittest.TestCase):
         self.c.close()
         self.failUnlessEqual(
             sorted(self.c.crs.keys()),
-            ['datum', 'ellps', 'no_defs', 'proj'])
+            ['datum', 'no_defs', 'proj'])
 
     def test_meta(self):
         self.failUnlessEqual(
@@ -179,11 +182,15 @@ class GenericWritingTest(unittest.TestCase):
                 "test-no-iter.shp", 
                 "w", 
                 "ESRI Shapefile", 
-                schema=schema)
+                schema=schema,
+                encoding='Windows-1252')
 
     def tearDown(self):
         self.c.close()
 
+    def test_encoding(self):
+        self.assertEquals(self.c.encoding, 'Windows-1252')
+
     def test_no_iter(self):
         self.assertRaises(IOError, iter, self.c)
 
@@ -200,11 +207,17 @@ class PointWritingTest(unittest.TestCase):
             schema={
                 'geometry': 'Point', 
                 'properties': {'title': 'str', 'date': 'date'}},
-            crs={'init': "epsg:4326", 'no_defs': True})
+            crs={'init': "epsg:4326", 'no_defs': True},
+            encoding='utf-8')
 
     def tearDown(self):
         self.sink.close()
 
+    def test_cpg(self):
+        """Requires GDAL 1.9"""
+        self.sink.close()
+        self.failUnless(open("/tmp/point_writing_test.cpg").readline() == 'UTF-8')
+
     def test_write_one(self):
         self.failUnlessEqual(len(self.sink), 0)
         self.failUnlessEqual(self.sink.bounds, (0.0, 0.0, 0.0, 0.0))
